@@ -18,21 +18,23 @@
 
 package org.apache.skywalking.oap.meter.analyzer.k8s;
 
-import static java.util.Objects.requireNonNull;
+import com.google.common.cache.CacheBuilder;
+import com.google.common.cache.CacheLoader;
+import com.google.common.cache.LoadingCache;
+import io.fabric8.kubernetes.api.model.Pod;
+import io.fabric8.kubernetes.api.model.Service;
+import lombok.SneakyThrows;
+import org.apache.skywalking.library.kubernetes.KubernetesPods;
+import org.apache.skywalking.library.kubernetes.KubernetesServices;
+import org.apache.skywalking.library.kubernetes.ObjectID;
+
 import java.time.Duration;
 import java.util.Collection;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
-import org.apache.skywalking.library.kubernetes.KubernetesPods;
-import org.apache.skywalking.library.kubernetes.KubernetesServices;
-import org.apache.skywalking.library.kubernetes.ObjectID;
-import com.google.common.cache.CacheBuilder;
-import com.google.common.cache.CacheLoader;
-import com.google.common.cache.LoadingCache;
-import io.kubernetes.client.openapi.models.V1Pod;
-import io.kubernetes.client.openapi.models.V1Service;
-import lombok.SneakyThrows;
+
+import static java.util.Objects.requireNonNull;
 
 public class K8sInfoRegistry {
     private final static K8sInfoRegistry INSTANCE = new K8sInfoRegistry();
@@ -51,6 +53,7 @@ public class K8sInfoRegistry {
                     .namespace(it.getMetadata().getNamespace())
                     .build())
                 .orElse(ObjectID.EMPTY)));
+
         ipServiceMap = CacheBuilder.newBuilder()
             .expireAfterWrite(Duration.ofMinutes(3))
             .build(CacheLoader.from(ip -> KubernetesServices.INSTANCE
@@ -73,10 +76,11 @@ public class K8sInfoRegistry {
                     .build())
                 .findFirst()
                 .orElse(ObjectID.EMPTY)));
+
         podServiceMap = CacheBuilder.newBuilder()
             .expireAfterWrite(Duration.ofMinutes(3))
             .build(CacheLoader.from(podObjectID -> {
-                final Optional<V1Pod> pod = KubernetesPods.INSTANCE
+                final Optional<Pod> pod = KubernetesPods.INSTANCE
                     .findByObjectID(
                         ObjectID
                             .builder()
@@ -90,10 +94,11 @@ public class K8sInfoRegistry {
                     return ObjectID.EMPTY;
                 }
 
-                final Optional<V1Service> service = KubernetesServices.INSTANCE
+                final Optional<Service> service = KubernetesServices.INSTANCE
                     .list()
                     .stream()
                     .filter(it -> it.getMetadata() != null)
+                    .filter(it -> Objects.equals(it.getMetadata().getNamespace(), pod.get().getMetadata().getNamespace()))
                     .filter(it -> it.getSpec() != null)
                     .filter(it -> requireNonNull(it.getSpec()).getSelector() != null)
                     .filter(it -> {
