@@ -20,66 +20,45 @@ package org.apache.skywalking.oap.meter.analyzer.dsl;
 
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
-import io.kubernetes.client.openapi.models.V1LoadBalancerIngress;
-import io.kubernetes.client.openapi.models.V1LoadBalancerStatus;
-import io.kubernetes.client.openapi.models.V1ObjectMeta;
-import io.kubernetes.client.openapi.models.V1Pod;
-import io.kubernetes.client.openapi.models.V1PodStatus;
-import io.kubernetes.client.openapi.models.V1Service;
-import io.kubernetes.client.openapi.models.V1ServiceSpec;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Map;
-import java.util.Optional;
-import io.kubernetes.client.openapi.models.V1ServiceStatus;
+import io.fabric8.kubernetes.api.model.LoadBalancerIngress;
+import io.fabric8.kubernetes.api.model.LoadBalancerStatus;
+import io.fabric8.kubernetes.api.model.ObjectMeta;
+import io.fabric8.kubernetes.api.model.Pod;
+import io.fabric8.kubernetes.api.model.PodStatus;
+import io.fabric8.kubernetes.api.model.Service;
+import io.fabric8.kubernetes.api.model.ServiceSpec;
+import io.fabric8.kubernetes.api.model.ServiceStatus;
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.skywalking.library.kubernetes.KubernetesClient;
 import org.apache.skywalking.library.kubernetes.KubernetesPods;
 import org.apache.skywalking.library.kubernetes.KubernetesServices;
 import org.apache.skywalking.library.kubernetes.ObjectID;
 import org.apache.skywalking.oap.meter.analyzer.dsl.tagOpt.Retag;
 import org.apache.skywalking.oap.server.core.analysis.IDManager;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 import org.mockito.Mockito;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PowerMockIgnore;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
-import org.powermock.modules.junit4.PowerMockRunnerDelegate;
+import org.mockito.junit.jupiter.MockitoExtension;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 import org.powermock.reflect.Whitebox;
 
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.Map;
+import java.util.Optional;
+
 import static com.google.common.collect.ImmutableMap.of;
-import static org.hamcrest.CoreMatchers.is;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.fail;
+import static org.assertj.core.api.AssertionsForClassTypes.assertThat;
+import static org.junit.jupiter.api.Assertions.fail;
+import static org.mockito.Mockito.when;
 
 @Slf4j
-@PowerMockIgnore({"javax.net.ssl.*", "javax.management.*"})
-@RunWith(PowerMockRunner.class)
-@PowerMockRunnerDelegate(Parameterized.class)
-@PrepareForTest({KubernetesPods.class, KubernetesServices.class, KubernetesClient.class})
+@ExtendWith(MockitoExtension.class)
+@MockitoSettings(strictness = Strictness.WARN)
 public class K8sTagTest {
-
-    @Parameterized.Parameter
-    public String name;
-
-    @Parameterized.Parameter(1)
-    public ImmutableMap<String, SampleFamily> input;
-
-    @Parameterized.Parameter(2)
-    public String expression;
-
-    @Parameterized.Parameter(3)
-    public Result want;
-
-    @Parameterized.Parameter(4)
-    public boolean isThrow;
-
-    @Parameterized.Parameters(name = "{index}: {0}")
     public static Collection<Object[]> data() {
         return Arrays.asList(new Object[][] {
             {
@@ -256,10 +235,8 @@ public class K8sTagTest {
     }
 
     @SneakyThrows
-    @Before
+    @BeforeEach
     public void setup() {
-        PowerMockito.mockStatic(KubernetesClient.class);
-
         Whitebox.setInternalState(KubernetesServices.class, "INSTANCE",
                                   Mockito.mock(KubernetesServices.class)
         );
@@ -267,31 +244,32 @@ public class K8sTagTest {
                                   Mockito.mock(KubernetesPods.class)
         );
 
-        PowerMockito.when(KubernetesServices.INSTANCE.list()).thenReturn(ImmutableList.of(
+        when(KubernetesServices.INSTANCE.list()).thenReturn(ImmutableList.of(
                 mockService("nginx-service", "default", of("run", "nginx"), "2.2.2.1"),
                 mockService("kube-state-metrics", "kube-system", of("run", "kube-state-metrics"), "2.2.2.2")));
         ImmutableList.of(
             mockService("nginx-service", "default", of("run", "nginx"), "2.2.2.1"),
             mockService("kube-state-metrics", "kube-system", of("run", "kube-state-metrics"), "2.2.2.2"))
             .forEach(svc ->
-                PowerMockito
-                .when(KubernetesServices.INSTANCE.findByID(ObjectID.builder().namespace(svc.getMetadata().getNamespace()).name(svc.getMetadata().getName()).build()))
+                when(KubernetesServices.INSTANCE.findByID(ObjectID.builder().namespace(svc.getMetadata().getNamespace()).name(svc.getMetadata().getName()).build()))
                 .thenReturn(Optional.of(svc))
             );
         ImmutableList.of(
             mockPod("my-nginx-5dc4865748-mbczh", "default", of("run", "nginx"), "1.1.1.1"),
             mockPod("kube-state-metrics-6f979fd498-z7xwx", "kube-system", of("run", "kube-state-metrics"), "1.1.1.2"))
             .forEach(pod -> {
-                PowerMockito
-                .when(KubernetesPods.INSTANCE.findByIP(pod.getStatus().getPodIP()))
-                .thenReturn(Optional.of(pod));
-                PowerMockito
-                .when(KubernetesPods.INSTANCE.findByObjectID(ObjectID.builder().name(pod.getMetadata().getName()).namespace(pod.getMetadata().getNamespace()).build())).thenReturn(Optional.of(pod));
+                when(KubernetesPods.INSTANCE.findByIP(pod.getStatus().getPodIP())).thenReturn(Optional.of(pod));
+                when(KubernetesPods.INSTANCE.findByObjectID(ObjectID.builder().name(pod.getMetadata().getName()).namespace(pod.getMetadata().getNamespace()).build())).thenReturn(Optional.of(pod));
         });
     }
 
-    @Test
-    public void test() {
+    @ParameterizedTest(name = "{index}: {0}")
+    @MethodSource("data")
+    public void test(String name,
+                     ImmutableMap<String, SampleFamily> input,
+                     String expression,
+                     Result want,
+                     boolean isThrow) {
         Expression e = DSL.parse(expression);
         Result r = null;
         try {
@@ -306,13 +284,13 @@ public class K8sTagTest {
         if (isThrow) {
             fail("Should throw something");
         }
-        assertThat(r, is(want));
+        assertThat(r).isEqualTo(want);
     }
 
-    private V1Service mockService(String name, String namespace, Map<String, String> selector, String ipAddress) {
-        V1Service service = new V1Service();
-        V1ObjectMeta serviceMeta = new V1ObjectMeta();
-        V1ServiceSpec v1ServiceSpec = new V1ServiceSpec();
+    private Service mockService(String name, String namespace, Map<String, String> selector, String ipAddress) {
+        Service service = new Service();
+        ObjectMeta serviceMeta = new ObjectMeta();
+        ServiceSpec v1ServiceSpec = new ServiceSpec();
 
         serviceMeta.setName(name);
         serviceMeta.setNamespace(namespace);
@@ -320,9 +298,9 @@ public class K8sTagTest {
         v1ServiceSpec.setSelector(selector);
         service.setSpec(v1ServiceSpec);
 
-        final V1ServiceStatus v1ServiceStatus = new V1ServiceStatus();
-        final V1LoadBalancerStatus balancerStatus = new V1LoadBalancerStatus();
-        final V1LoadBalancerIngress loadBalancerIngress = new V1LoadBalancerIngress();
+        final ServiceStatus v1ServiceStatus = new ServiceStatus();
+        final LoadBalancerStatus balancerStatus = new LoadBalancerStatus();
+        final LoadBalancerIngress loadBalancerIngress = new LoadBalancerIngress();
         loadBalancerIngress.setIp(ipAddress);
         balancerStatus.setIngress(Arrays.asList(loadBalancerIngress));
         v1ServiceStatus.setLoadBalancer(balancerStatus);
@@ -331,13 +309,13 @@ public class K8sTagTest {
         return service;
     }
 
-    private V1Pod mockPod(String name, String namespace, Map<String, String> labels, String ipAddress) {
-        V1Pod v1Pod = new V1Pod();
-        V1ObjectMeta podMeta = new V1ObjectMeta();
+    private Pod mockPod(String name, String namespace, Map<String, String> labels, String ipAddress) {
+        Pod v1Pod = new Pod();
+        ObjectMeta podMeta = new ObjectMeta();
         podMeta.setName(name);
         podMeta.setNamespace(namespace);
         podMeta.setLabels(labels);
-        final V1PodStatus status = new V1PodStatus();
+        final PodStatus status = new PodStatus();
         status.setPodIP(ipAddress);
         v1Pod.setStatus(status);
         v1Pod.setMetadata(podMeta);
