@@ -494,7 +494,7 @@ public class ScopeTest {
                 new HashMap<MeterEntity, Sample[]>() {
                     {
                         put(
-                            MeterEntity.newServiceRelation("productpage", "details", DetectPoint.CLIENT, Layer.GENERAL),
+                            MeterEntity.newServiceRelation("productpage", "details", DetectPoint.CLIENT, Layer.GENERAL, 0),
                             new Sample[] {
                                 Sample.builder()
                                       .labels(of())
@@ -503,7 +503,7 @@ public class ScopeTest {
                             }
                         );
                         put(
-                            MeterEntity.newServiceRelation("productpage", "reviews", DetectPoint.CLIENT, Layer.GENERAL),
+                            MeterEntity.newServiceRelation("productpage", "reviews", DetectPoint.CLIENT, Layer.GENERAL, 0),
                             new Sample[] {
                                 Sample.builder()
                                       .labels(of())
@@ -514,6 +514,45 @@ public class ScopeTest {
                     }
                 }
             },
+            {
+                "sum_service_relation_with_component",
+                of("envoy_cluster_metrics_up_cx_active", SampleFamilyBuilder.newBuilder(
+                    Sample.builder()
+                        .labels(of("app", "productpage", "cluster_name", "details", "env", "test", "component", "10"))
+                        .value(11)
+                        .name("envoy_cluster_metrics_up_cx_active")
+                        .build(),
+                    Sample.builder()
+                        .labels(of("app", "productpage", "cluster_name", "reviews", "env", "test", "component", "10"))
+                        .value(16)
+                        .name("envoy_cluster_metrics_up_cx_active")
+                        .build()
+                ).build()),
+                "envoy_cluster_metrics_up_cx_active.sum(['app' ,'cluster_name', 'env', 'component']).serviceRelation(DetectPoint.CLIENT, ['app', 'env'], ['cluster_name'], '-', Layer.GENERAL, 'component')",
+                false,
+                new HashMap<MeterEntity, Sample[]>() {
+                    {
+                        put(
+                            MeterEntity.newServiceRelation("productpage-test", "details", DetectPoint.CLIENT, Layer.GENERAL, 10),
+                            new Sample[] {
+                                Sample.builder()
+                                    .labels(of())
+                                    .value(11)
+                                    .name("envoy_cluster_metrics_up_cx_active").build()
+                            }
+                        );
+                        put(
+                            MeterEntity.newServiceRelation("productpage-test", "reviews", DetectPoint.CLIENT, Layer.GENERAL, 10),
+                            new Sample[] {
+                                Sample.builder()
+                                    .labels(of())
+                                    .value(16)
+                                    .name("envoy_cluster_metrics_up_cx_active").build()
+                            }
+                        );
+                    }
+                }
+            },
             {
                 "sum_process_relation",
                 of("rover_network_profiling_process_write_bytes", SampleFamilyBuilder.newBuilder(
