@@ -21,10 +21,12 @@ package org.apache.skywalking.oap.server.core.alarm.provider;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
+import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.regex.Pattern;
@@ -32,6 +34,16 @@ import java.util.stream.Collectors;
 import lombok.RequiredArgsConstructor;
 import lombok.ToString;
 import lombok.extern.slf4j.Slf4j;
+import org.antlr.v4.runtime.CharStreams;
+import org.antlr.v4.runtime.CommonTokenStream;
+import org.antlr.v4.runtime.tree.ParseTree;
+import org.apache.skywalking.mqe.rt.exception.ParseErrorListener;
+import org.apache.skywalking.mqe.rt.grammar.MQELexer;
+import org.apache.skywalking.mqe.rt.grammar.MQEParser;
+import org.apache.skywalking.mqe.rt.type.ExpressionResult;
+import org.apache.skywalking.mqe.rt.type.ExpressionResultType;
+import org.apache.skywalking.mqe.rt.type.MQEValues;
+import org.apache.skywalking.oap.server.core.alarm.provider.expr.rt.AlarmMQEVisitor;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
 import org.apache.skywalking.oap.server.core.alarm.AlarmMessage;
 import org.apache.skywalking.oap.server.core.alarm.MetaInAlarm;
@@ -58,59 +70,44 @@ public class RunningRule {
 
     private final String ruleName;
     private final int period;
-    private final String metricsName;
-    private final Threshold threshold;
-    private final OP op;
-    private final int countThreshold;
+    private final String expression;
     private final int silencePeriod;
-    private final Map<MetaInAlarm, Window> windows;
-    private volatile MetricsValueType valueType;
+    private final Map<AlarmEntity, Window> windows;
     private final List<String> includeNames;
     private final List<String> excludeNames;
     private final Pattern includeNamesRegex;
     private final Pattern excludeNamesRegex;
-    private final List<String> includeLabels;
-    private final List<String> excludeLabels;
-    private final Pattern includeLabelsRegex;
-    private final Pattern excludeLabelsRegex;
     private final AlarmMessageFormatter formatter;
-    private final boolean onlyAsCondition;
     private final List<Tag> tags;
+    private final Set<String> hooks;
+    private final Set<String> includeMetrics;
+    private final ParseTree exprTree;
 
     public RunningRule(AlarmRule alarmRule) {
-        metricsName = alarmRule.getMetricsName();
+        expression = alarmRule.getExpression();
         this.ruleName = alarmRule.getAlarmRuleName();
-
+        this.includeMetrics = alarmRule.getIncludeMetrics();
         // Init the empty window for alarming rule.
         windows = new ConcurrentHashMap<>();
-
         period = alarmRule.getPeriod();
-
-        threshold = new Threshold(alarmRule.getAlarmRuleName(), alarmRule.getThreshold());
-        op = OP.get(alarmRule.getOp());
-
-        this.countThreshold = alarmRule.getCount();
         this.silencePeriod = alarmRule.getSilencePeriod();
-
         this.includeNames = alarmRule.getIncludeNames();
         this.excludeNames = alarmRule.getExcludeNames();
         this.includeNamesRegex = StringUtil.isNotEmpty(alarmRule.getIncludeNamesRegex()) ?
             Pattern.compile(alarmRule.getIncludeNamesRegex()) : null;
         this.excludeNamesRegex = StringUtil.isNotEmpty(alarmRule.getExcludeNamesRegex()) ?
             Pattern.compile(alarmRule.getExcludeNamesRegex()) : null;
-        this.includeLabels = alarmRule.getIncludeLabels();
-        this.excludeLabels = alarmRule.getExcludeLabels();
-        this.includeLabelsRegex = StringUtil.isNotEmpty(alarmRule.getIncludeLabelsRegex()) ?
-            Pattern.compile(alarmRule.getIncludeLabelsRegex()) : null;
-        this.excludeLabelsRegex = StringUtil.isNotEmpty(alarmRule.getExcludeLabelsRegex()) ?
-            Pattern.compile(alarmRule.getExcludeLabelsRegex()) : null;
         this.formatter = new AlarmMessageFormatter(alarmRule.getMessage());
-        this.onlyAsCondition = alarmRule.isOnlyAsCondition();
         this.tags = alarmRule.getTags()
                              .entrySet()
                              .stream()
                              .map(e -> new Tag(e.getKey(), e.getValue()))
                              .collect(Collectors.toList());
+        this.hooks = alarmRule.getHooks();
+        MQELexer lexer = new MQELexer(CharStreams.fromString(alarmRule.getExpression()));
+        MQEParser parser = new MQEParser(new CommonTokenStream(lexer));
+        parser.addErrorListener(new ParseErrorListener());
+        this.exprTree = parser.expression();
     }
 
     /**
@@ -121,10 +118,10 @@ public class RunningRule {
      * @param metrics includes the values.
      */
     public void in(MetaInAlarm meta, Metrics metrics) {
-        if (!meta.getMetricsName().equals(metricsName)) {
+        if (!includeMetrics.contains(meta.getMetricsName())) {
             //Don't match rule, exit.
             if (log.isTraceEnabled()) {
-                log.trace("Metric names are inconsistent, {}-{}", meta.getMetricsName(), metricsName);
+                log.trace("Metric name not in the expression, {}-{}", expression, meta.getMetricsName());
             }
             return;
         }
@@ -134,42 +131,11 @@ public class RunningRule {
             return;
         }
 
-        if (valueType == null) {
-            if (metrics instanceof LongValueHolder) {
-                valueType = MetricsValueType.LONG;
-                threshold.setType(MetricsValueType.LONG);
-            } else if (metrics instanceof IntValueHolder) {
-                valueType = MetricsValueType.INT;
-                threshold.setType(MetricsValueType.INT);
-            } else if (metrics instanceof DoubleValueHolder) {
-                valueType = MetricsValueType.DOUBLE;
-                threshold.setType(MetricsValueType.DOUBLE);
-            } else if (metrics instanceof MultiIntValuesHolder) {
-                valueType = MetricsValueType.MULTI_INTS;
-                threshold.setType(MetricsValueType.MULTI_INTS);
-            } else if (metrics instanceof LabeledValueHolder) {
-                if (((LabeledValueHolder) metrics).getValue().keys().stream()
-                                                  .noneMatch(label -> validate(
-                                                      label,
-                                                      includeLabels,
-                                                      excludeLabels,
-                                                      includeLabelsRegex,
-                                                      excludeLabelsRegex
-                                                  ))) {
-                    return;
-                }
-                valueType = MetricsValueType.LABELED_LONG;
-                threshold.setType(MetricsValueType.LONG);
-            } else {
-                log.warn("Unsupported value type {}", valueType);
-                return;
-            }
-        }
+        AlarmEntity entity = new AlarmEntity(
+            meta.getScope(), meta.getScopeId(), meta.getName(), meta.getId0(), meta.getId1());
 
-        if (valueType != null) {
-            Window window = windows.computeIfAbsent(meta, ignored -> new Window(period));
-            window.add(metrics);
-        }
+        Window window = windows.computeIfAbsent(entity, ignored -> new Window(period));
+        window.add(meta.getMetricsName(), metrics);
     }
 
     /**
@@ -233,21 +199,21 @@ public class RunningRule {
     public List<AlarmMessage> check() {
         List<AlarmMessage> alarmMessageList = new ArrayList<>(30);
 
-        windows.forEach((meta, window) -> {
+        windows.forEach((alarmEntity, window) -> {
             Optional<AlarmMessage> alarmMessageOptional = window.checkAlarm();
             if (alarmMessageOptional.isPresent()) {
                 AlarmMessage alarmMessage = alarmMessageOptional.get();
-                alarmMessage.setScopeId(meta.getScopeId());
-                alarmMessage.setScope(meta.getScope());
-                alarmMessage.setName(meta.getName());
-                alarmMessage.setId0(meta.getId0());
-                alarmMessage.setId1(meta.getId1());
+                alarmMessage.setScopeId(alarmEntity.getScopeId());
+                alarmMessage.setScope(alarmEntity.getScope());
+                alarmMessage.setName(alarmEntity.getName());
+                alarmMessage.setId0(alarmEntity.getId0());
+                alarmMessage.setId1(alarmEntity.getId1());
                 alarmMessage.setRuleName(this.ruleName);
-                alarmMessage.setAlarmMessage(formatter.format(meta));
-                alarmMessage.setOnlyAsCondition(this.onlyAsCondition);
+                alarmMessage.setAlarmMessage(formatter.format(alarmEntity));
                 alarmMessage.setStartTime(System.currentTimeMillis());
                 alarmMessage.setPeriod(this.period);
                 alarmMessage.setTags(this.tags);
+                alarmMessage.setHooks(this.hooks);
                 alarmMessageList.add(alarmMessage);
             }
         });
@@ -261,10 +227,9 @@ public class RunningRule {
      */
     public class Window {
         private LocalDateTime endTime;
-        private int period;
+        private final int period;
         private int silenceCountdown;
-
-        private LinkedList<Metrics> values;
+        private LinkedList<Map<String, Metrics>> values;
         private ReentrantLock lock = new ReentrantLock();
 
         public Window(int period) {
@@ -303,7 +268,7 @@ public class RunningRule {
             }
         }
 
-        public void add(Metrics metrics) {
+        public void add(String metricsName, Metrics metrics) {
             long bucket = metrics.getTimeBucket();
 
             LocalDateTime timeBucket = TIME_BUCKET_FORMATTER.parseLocalDateTime(bucket + "");
@@ -315,6 +280,7 @@ public class RunningRule {
                     this.endTime = timeBucket;
                 }
                 int minutes = Minutes.minutesBetween(timeBucket, this.endTime).getMinutes();
+                //timeBucket > endTime
                 if (minutes < 0) {
                     this.moveTo(timeBucket);
                     minutes = 0;
@@ -331,8 +297,15 @@ public class RunningRule {
                     }
                     return;
                 }
-
-                this.values.set(values.size() - minutes - 1, metrics);
+                int index = values.size() - minutes - 1;
+                Map<String, Metrics> metricsMap = values.get(index);
+                if (metricsMap == null) {
+                    metricsMap = new HashMap<>();
+                    metricsMap.put(metricsName, metrics);
+                    values.set(index, metricsMap);
+                } else {
+                    metricsMap.put(metricsName, metrics);
+                }
             } finally {
                 this.lock.unlock();
             }
@@ -361,81 +334,53 @@ public class RunningRule {
         }
 
         private boolean isMatch() {
-            int matchCount = 0;
-            for (Metrics metrics : values) {
-                if (metrics == null) {
-                    continue;
+            int isMatch = 0;
+            AlarmMQEVisitor visitor = new AlarmMQEVisitor(this.values, this.endTime);
+            ExpressionResult parseResult = visitor.visit(exprTree);
+            if (StringUtil.isNotBlank(parseResult.getError())) {
+                log.error("expression:" + expression + " error: " + parseResult.getError());
+                return false;
+            }
+            if (!parseResult.isBoolResult() ||
+                ExpressionResultType.SINGLE_VALUE != parseResult.getType() ||
+                CollectionUtils.isEmpty(parseResult.getResults())) {
+                return false;
+            }
+            if (!parseResult.isLabeledResult()) {
+                MQEValues mqeValues = parseResult.getResults().get(0);
+                if (mqeValues != null &&
+                    CollectionUtils.isNotEmpty(mqeValues.getValues()) &&
+                    mqeValues.getValues().get(0) != null) {
+                    isMatch = (int) mqeValues.getValues().get(0).getDoubleValue();
                 }
-
-                switch (valueType) {
-                    case LONG:
-                        long lvalue = ((LongValueHolder) metrics).getValue();
-                        long lexpected = RunningRule.this.threshold.getLongThreshold();
-                        if (op.test(lexpected, lvalue)) {
-                            matchCount++;
+            } else {
+                // if the result has multiple labels, when there is one label match, then the result is match
+                // for example in 5 minutes, the sum(percentile{_='P50,P75'} > 1000) >= 3
+                // percentile{_='P50,P75'} result is:
+                // P50(1000,1100,1200,1000,500), > 1000 2 times
+                // P75(2000,1500,1200,1000,500), > 1000 3 times
+                // percentile{_='P50,P75'} > 1000 result is:
+                // P50(0,1,1,0,0)
+                // P75(1,1,1,0,0)
+                // sum(percentile{_='P50,P75'} > 1000) >= 3 result is:
+                // P50(0)
+                // P75(1)
+                // then the isMatch is 1
+                for (MQEValues mqeValues : parseResult.getResults()) {
+                    if (mqeValues != null &&
+                        CollectionUtils.isNotEmpty(mqeValues.getValues()) &&
+                        mqeValues.getValues().get(0) != null) {
+                        isMatch = (int) mqeValues.getValues().get(0).getDoubleValue();
+                        if (isMatch == 1) {
+                            break;
                         }
-                        break;
-                    case INT:
-                        int ivalue = ((IntValueHolder) metrics).getValue();
-                        int iexpected = RunningRule.this.threshold.getIntThreshold();
-                        if (op.test(iexpected, ivalue)) {
-                            matchCount++;
-                        }
-                        break;
-                    case DOUBLE:
-                        double dvalue = ((DoubleValueHolder) metrics).getValue();
-                        double dexpected = RunningRule.this.threshold.getDoubleThreshold();
-                        if (op.test(dexpected, dvalue)) {
-                            matchCount++;
-                        }
-                        break;
-                    case MULTI_INTS:
-                        int[] ivalueArray = ((MultiIntValuesHolder) metrics).getValues();
-                        Integer[] iaexpected = RunningRule.this.threshold.getIntValuesThreshold();
-                        if (log.isTraceEnabled()) {
-                            log.trace("Value array is {}, expected array is {}", ivalueArray, iaexpected);
-                        }
-                        for (int i = 0; i < ivalueArray.length; i++) {
-                            ivalue = ivalueArray[i];
-                            Integer iNullableExpected = 0;
-                            if (iaexpected.length > i) {
-                                iNullableExpected = iaexpected[i];
-                                if (iNullableExpected == null) {
-                                    continue;
-                                }
-                            }
-                            if (op.test(iNullableExpected, ivalue)) {
-                                if (log.isTraceEnabled()) {
-                                    log.trace("Matched, expected {}, value {}", iNullableExpected, ivalue);
-                                }
-                                matchCount++;
-                                break;
-                            }
-                        }
-                        break;
-                    case LABELED_LONG:
-                        DataTable values = ((LabeledValueHolder) metrics).getValue();
-                        lexpected = RunningRule.this.threshold.getLongThreshold();
-                        if (values.keys().stream().anyMatch(label ->
-                                                                validate(
-                                                                    label,
-                                                                    RunningRule.this.includeLabels,
-                                                                    RunningRule.this.excludeLabels,
-                                                                    RunningRule.this.includeLabelsRegex,
-                                                                    RunningRule.this.excludeLabelsRegex
-                                                                )
-                                                                    && op.test(lexpected, values.get(label)))) {
-                            matchCount++;
-                        }
-                        break;
+                    }
                 }
             }
-
             if (log.isTraceEnabled()) {
-                log.trace("Match count is {}, threshold is {}", matchCount, countThreshold);
+                log.trace("Match expression is {}", expression);
             }
-            // Reach the threshold in current bucket.
-            return matchCount >= countThreshold;
+            return isMatch == 1;
         }
 
         private void init() {
@@ -446,37 +391,38 @@ public class RunningRule {
         }
     }
 
-    private LinkedList<TraceLogMetric> transformValues(final LinkedList<Metrics> values) {
-        LinkedList<TraceLogMetric> r = new LinkedList<>();
-        values.forEach(m -> {
-            if (m == null) {
-                r.add(null);
-                return;
+    private LinkedList<Map<String, TraceLogMetric>> transformValues(LinkedList<Map<String, Metrics>> values) {
+        LinkedList<Map<String, TraceLogMetric>> result = new LinkedList<>();
+        for (Map<String, Metrics> value : values) {
+            if (value == null) {
+                result.add(null);
+                continue;
             }
-            switch (valueType) {
-                case LONG:
-                    r.add(new TraceLogMetric(m.getTimeBucket(), new Number[] {((LongValueHolder) m).getValue()}));
-                    break;
-                case INT:
-                    r.add(new TraceLogMetric(m.getTimeBucket(), new Number[] {((IntValueHolder) m).getValue()}));
-                    break;
-                case DOUBLE:
-                    r.add(new TraceLogMetric(m.getTimeBucket(), new Number[] {((DoubleValueHolder) m).getValue()}));
-                    break;
-                case MULTI_INTS:
+            value.forEach((name, m) -> {
+                Map<String, TraceLogMetric> r = new HashMap<>();
+                result.add(r);
+                if (m instanceof LongValueHolder) {
+                    r.put(name, new TraceLogMetric(m.getTimeBucket(), new Number[] {((LongValueHolder) m).getValue()}));
+                } else if (m instanceof IntValueHolder) {
+                    r.put(name, new TraceLogMetric(m.getTimeBucket(), new Number[] {((IntValueHolder) m).getValue()}));
+                } else if (m instanceof DoubleValueHolder) {
+                    r.put(name, new TraceLogMetric(m.getTimeBucket(), new Number[] {((DoubleValueHolder) m).getValue()}));
+                } else if (m instanceof MultiIntValuesHolder) {
                     int[] iArr = ((MultiIntValuesHolder) m).getValues();
-                    r.add(new TraceLogMetric(m.getTimeBucket(), Arrays.stream(iArr).boxed().toArray(Number[]::new)));
-                    break;
-                case LABELED_LONG:
+                    r.put(name, new TraceLogMetric(m.getTimeBucket(), Arrays.stream(iArr).boxed().toArray(Number[]::new)));
+                } else if (m instanceof LabeledValueHolder) {
                     DataTable dt = ((LabeledValueHolder) m).getValue();
                     TraceLogMetric l = new TraceLogMetric(
                         m.getTimeBucket(), dt.sortedValues(Comparator.naturalOrder())
                                              .toArray(new Number[0]));
                     l.labels = dt.sortedKeys(Comparator.naturalOrder()).toArray(new String[0]);
-                    r.add(l);
-            }
-        });
-        return r;
+                    r.put(name, l);
+                } else {
+                    log.warn("Unsupported metrics {}", m);
+                }
+            });
+        }
+        return result;
     }
 
     @RequiredArgsConstructor
