@@ -20,26 +20,27 @@ package org.apache.skywalking.oap.server.core.analysis.worker;
 
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
-import java.util.Map;
 import java.util.Optional;
-import java.util.Properties;
-import java.util.concurrent.ConcurrentHashMap;
 import java.util.stream.Collectors;
 import lombok.extern.slf4j.Slf4j;
+import org.apache.skywalking.oap.server.core.CoreModule;
 import org.apache.skywalking.oap.server.core.UnexpectedException;
+import org.apache.skywalking.oap.server.core.analysis.DownSampling;
+import org.apache.skywalking.oap.server.core.analysis.TimeBucket;
 import org.apache.skywalking.oap.server.core.analysis.data.MergableBufferedData;
 import org.apache.skywalking.oap.server.core.analysis.data.ReadWriteSafeCache;
 import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
 import org.apache.skywalking.oap.server.core.exporter.ExportEvent;
+import org.apache.skywalking.oap.server.core.status.BootingStatus;
+import org.apache.skywalking.oap.server.core.status.ClusterStatus;
+import org.apache.skywalking.oap.server.core.status.ServerStatusService;
+import org.apache.skywalking.oap.server.core.status.ServerStatusWatcher;
 import org.apache.skywalking.oap.server.core.storage.IMetricsDAO;
 import org.apache.skywalking.oap.server.core.storage.SessionCacheCallback;
 import org.apache.skywalking.oap.server.core.storage.model.Model;
 import org.apache.skywalking.oap.server.core.worker.AbstractWorker;
-import org.apache.skywalking.oap.server.library.client.request.InsertRequest;
 import org.apache.skywalking.oap.server.library.client.request.PrepareRequest;
-import org.apache.skywalking.oap.server.library.client.request.UpdateRequest;
 import org.apache.skywalking.oap.server.library.datacarrier.DataCarrier;
 import org.apache.skywalking.oap.server.library.datacarrier.consumer.BulkConsumePool;
 import org.apache.skywalking.oap.server.library.datacarrier.consumer.ConsumerPoolFactory;
@@ -54,32 +55,15 @@ import org.apache.skywalking.oap.server.telemetry.api.MetricsTag;
  * MetricsPersistentWorker is an extension of {@link PersistenceWorker} and focuses on the Metrics data persistent.
  */
 @Slf4j
-public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
-    /**
-     * The counter of MetricsPersistentWorker instance, to calculate session timeout offset.
-     */
-    private static long SESSION_TIMEOUT_OFFSITE_COUNTER = 0;
-
+public class MetricsPersistentWorker extends PersistenceWorker<Metrics> implements ServerStatusWatcher {
     private final Model model;
-    /**
-     * The session cache holds the latest metrics in-memory.
-     * There are two ways to make sure metrics in-cache,
-     * 1. Metrics is read from the Database through {@link #loadFromStorage(List)}
-     * 2. The built {@link InsertRequest} executed successfully.
-     *
-     * There are two cases to remove metrics from the cache.
-     * 1. The metrics expired.
-     * 2. The built {@link UpdateRequest} executed failure, which could be caused
-     * (1) Database error. (2) No data updated, such as the counter of update statement is 0 in JDBC.
-     */
-    private final Map<Metrics, Metrics> sessionCache;
+    private final MetricsSessionCache sessionCache;
     private final IMetricsDAO metricsDAO;
     private final Optional<AbstractWorker<Metrics>> nextAlarmWorker;
     private final Optional<AbstractWorker<ExportEvent>> nextExportWorker;
     private final DataCarrier<Metrics> dataCarrier;
     private final Optional<MetricsTransWorker> transWorker;
     private final boolean supportUpdate;
-    private long sessionTimeout;
     /**
      * The counter of L2 aggregation.
      */
@@ -106,6 +90,16 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
      * @since 8.7.0 TTL settings from {@link org.apache.skywalking.oap.server.core.CoreModuleConfig#getMetricsDataTTL()}
      */
     private int metricsDataTTL;
+    /**
+     * @since 9.4.0
+     */
+    private final ServerStatusService serverStatusService;
+    /**
+     * The time bucket is 0 or in minute dimensionality of the system in the latest stability status.
+     *
+     * @since 9.4.0
+     */
+    private volatile long timeOfLatestStabilitySts = 0;
 
     MetricsPersistentWorker(ModuleDefineHolder moduleDefineHolder, Model model, IMetricsDAO metricsDAO,
                             AbstractWorker<Metrics> nextAlarmWorker, AbstractWorker<ExportEvent> nextExportWorker,
@@ -113,17 +107,12 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
                             long storageSessionTimeout, int metricsDataTTL, MetricStreamKind kind) {
         super(moduleDefineHolder, new ReadWriteSafeCache<>(new MergableBufferedData(), new MergableBufferedData()));
         this.model = model;
-        // Due to the cache would be updated depending on final storage implementation,
-        // the map/cache could be updated concurrently.
-        // Set to ConcurrentHashMap in order to avoid HashMap deadlock.
-        // Since 9.3.0
-        this.sessionCache = new ConcurrentHashMap<>(100);
+        this.sessionCache = new MetricsSessionCache(storageSessionTimeout);
         this.metricsDAO = metricsDAO;
         this.nextAlarmWorker = Optional.ofNullable(nextAlarmWorker);
         this.nextExportWorker = Optional.ofNullable(nextExportWorker);
         this.transWorker = Optional.ofNullable(transWorker);
         this.supportUpdate = supportUpdate;
-        this.sessionTimeout = storageSessionTimeout;
         this.persistentCounter = 0;
         this.persistentMod = 1;
         this.metricsDataTTL = metricsDataTTL;
@@ -166,7 +155,10 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
             "metrics_persistent_cache", "The counter of metrics status, new or cached.",
             new MetricsTag.Keys("status"), new MetricsTag.Values("cached")
         );
-        SESSION_TIMEOUT_OFFSITE_COUNTER++;
+        serverStatusService = moduleDefineHolder.find(CoreModule.NAME).provider().getService(ServerStatusService.class);
+        if (model.getDownsampling().equals(DownSampling.Minute)) {
+            serverStatusService.registerWatcher(this);
+        }
     }
 
     /**
@@ -184,9 +176,7 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
              supportUpdate, storageSessionTimeout, metricsDataTTL, kind
         );
         // For a down-sampling metrics, we prolong the session timeout for 4 times, nearly 5 minutes.
-        // And add offset according to worker creation sequence, to avoid context clear overlap,
-        // eventually optimize load of IDs reading.
-        this.sessionTimeout = this.sessionTimeout * 4 + SESSION_TIMEOUT_OFFSITE_COUNTER * 200;
+        sessionCache.setTimeoutThreshold(storageSessionTimeout * 4);
         // The down sampling level worker executes every 4 periods.
         this.persistentMod = 4;
     }
@@ -258,6 +248,7 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
             for (Metrics metrics : metricsList) {
                 Metrics cachedMetrics = sessionCache.get(metrics);
                 if (cachedMetrics != null) {
+                    cachedMetrics.setLastUpdateTimestamp(timestamp);
                     /*
                      * If the metrics is not supportUpdate, defined through MetricsExtension#supportUpdate,
                      * then no merge and further process happens.
@@ -280,7 +271,6 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
                             new SessionCacheCallback(sessionCache, cachedMetrics)
                         ));
                     nextWorker(cachedMetrics);
-                    cachedMetrics.setLastUpdateTimestamp(timestamp);
                 } else {
                     metrics.calculate();
                     prepareRequests.add(
@@ -321,7 +311,7 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
             List<Metrics> notInCacheMetrics =
                 metrics.stream()
                        .filter(m -> {
-                           final Metrics cachedValue = sessionCache.get(m);
+                           final Metrics cachedValue = requireInitialization(m);
                            // the metric is tagged `not in cache`.
                            if (cachedValue == null) {
                                return true;
@@ -331,7 +321,7 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
                            // This is a cache-DB inconsistent case:
                            // Metrics keep coming due to traffic, but the entity in the
                            // database has been removed due to TTL.
-                           if (!model.isTimeRelativeID() && supportUpdate) {
+                           if (!model.isTimeRelativeID()) {
                                // Mostly all updatable metadata level metrics are required to do this check.
 
                                if (metricsDAO.isExpiredCache(model, cachedValue, currentTimeMillis, metricsDataTTL)) {
@@ -350,8 +340,10 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
             if (notInCacheMetrics.isEmpty()) {
                 return;
             }
-
-            metricsDAO.multiGet(model, notInCacheMetrics).forEach(m -> sessionCache.put(m, m));
+            metricsDAO.multiGet(model, notInCacheMetrics).forEach(m -> {
+                m.setLastUpdateTimestamp(currentTimeMillis);
+                sessionCache.put(m);
+            });
         } catch (final Exception e) {
             log.error("Failed to load metrics for merging", e);
         }
@@ -359,15 +351,62 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
 
     @Override
     public void endOfRound() {
-        Iterator<Metrics> iterator = sessionCache.values().iterator();
-        long timestamp = System.currentTimeMillis();
-        while (iterator.hasNext()) {
-            Metrics metrics = iterator.next();
+        sessionCache.removeExpired();
+    }
 
-            if (metrics.isExpired(timestamp, sessionTimeout)) {
-                iterator.remove();
-            }
+    /**
+     * Check the metrics whether in the cache, and whether the worker should go further to load from database.
+     *
+     * @param metrics the metrics in the streaming process.
+     * @return metrics in cache or null if try to read the metrics from the database.
+     */
+    private Metrics requireInitialization(Metrics metrics) {
+        final Metrics cached = sessionCache.get(metrics);
+
+        // All cached metrics, it at least had been written once.
+        if (cached != null) {
+            return cached;
         }
+
+        // If the metrics do not have time bucket relative ID
+        // it is treated as high dimensionality metrics.
+        // Policy, always try load from the database when miss in the cache.
+        if (!model.isTimeRelativeID()) {
+            return null;
+        }
+
+        // When
+        // (1) the time bucket of the server's latest stability status is provided
+        //     1.1 the OAP has booted successfully
+        //     1.2 the current dimensionality is in minute
+        //     1.3 the OAP cluster is rebalanced due to scaling
+        // (2) the metrics are from the time after the timeOfLatestStabilitySts
+        // (3) the metrics don't exist in the cache
+        // the kernel should NOT try to load it from the database.
+        //
+        // Notice, about condition (2),
+        // for the specific minute of booted successfully, the metrics are expected to load from database when
+        // it doesn't exist in the cache.
+        if (timeOfLatestStabilitySts > 0 &&
+            metrics.getTimeBucket() > timeOfLatestStabilitySts
+            && cached == null) {
+            // Return metrics as input to avoid reading from database.
+            return metrics;
+        }
+
+        return null;
+    }
+
+    @Override
+    public void onServerBooted(final BootingStatus bootingStatus) {
+        timeOfLatestStabilitySts = TimeBucket.getMinuteTimeBucket(
+            bootingStatus.getUptime());
+    }
+
+    @Override
+    public void onClusterRebalanced(final ClusterStatus clusterStatus) {
+        timeOfLatestStabilitySts = TimeBucket.getMinuteTimeBucket(
+            clusterStatus.getRebalancedTime());
     }
 
     /**
@@ -376,11 +415,6 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
      * ID is declared through {@link Object#hashCode()} and {@link Object#equals(Object)} as usual.
      */
     private class PersistentConsumer implements IConsumer<Metrics> {
-        @Override
-        public void init(final Properties properties) {
-
-        }
-
         @Override
         public void consume(List<Metrics> data) {
             MetricsPersistentWorker.this.onWork(data);
@@ -390,9 +424,5 @@ public class MetricsPersistentWorker extends PersistenceWorker<Metrics> {
         public void onError(List<Metrics> data, Throwable t) {
             log.error(t.getMessage(), t);
         }
-
-        @Override
-        public void onExit() {
-        }
     }
 }
