@@ -24,6 +24,7 @@ import lombok.Data;
 import org.apache.skywalking.oap.server.core.analysis.Stream;
 import org.apache.skywalking.oap.server.core.analysis.record.Record;
 import org.apache.skywalking.oap.server.core.analysis.worker.RecordStreamProcessor;
+import org.apache.skywalking.oap.server.core.storage.StorageID;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
 import org.apache.skywalking.oap.server.core.storage.annotation.Column;
 import org.apache.skywalking.oap.server.core.storage.type.Convert2Entity;
@@ -49,27 +50,34 @@ public class EBPFProfilingDataRecord extends Record {
     public static final String DATA_BINARY = "dump_binary";
     public static final String UPLOAD_TIME = "upload_time";
 
-    @Column(columnName = TASK_ID, length = 600)
+    @Column(name = TASK_ID)
     @BanyanDB.SeriesID(index = 0)
     private String taskId;
-    @Column(columnName = SCHEDULE_ID, length = 600)
+    @Column(name = SCHEDULE_ID)
     private String scheduleId;
-    @Column(columnName = STACK_ID_LIST)
+    @Column(name = STACK_ID_LIST)
     private String stackIdList;
-    @Column(columnName = TARGET_TYPE)
+    @Column(name = TARGET_TYPE)
     private int targetType;
-    @Column(columnName = DATA_BINARY, storageOnly = true)
+    @Column(name = DATA_BINARY, storageOnly = true)
     private byte[] dataBinary;
-    @Column(columnName = UPLOAD_TIME)
+    @Column(name = UPLOAD_TIME)
     private long uploadTime;
 
     @Override
-    public String id() {
-        return Hashing.sha256().newHasher()
-                      .putString(scheduleId, Charsets.UTF_8)
-                      .putString(stackIdList, Charsets.UTF_8)
-                      .putLong(uploadTime)
-                      .hash().toString();
+    public StorageID id() {
+        return new StorageID().appendMutant(
+            new String[] {
+                SCHEDULE_ID,
+                STACK_ID_LIST,
+                UPLOAD_TIME
+            },
+            Hashing.sha256().newHasher()
+                   .putString(scheduleId, Charsets.UTF_8)
+                   .putString(stackIdList, Charsets.UTF_8)
+                   .putLong(uploadTime)
+                   .hash().toString()
+        );
     }
 
     public static class Builder implements StorageBuilder<EBPFProfilingDataRecord> {
