@@ -21,8 +21,6 @@ package org.apache.skywalking.oap.server.core.zipkin;
 import com.google.gson.Gson;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
-import java.util.List;
-import java.util.Map;
 import lombok.Getter;
 import lombok.Setter;
 import org.apache.skywalking.oap.server.core.Const;
@@ -30,9 +28,10 @@ import org.apache.skywalking.oap.server.core.analysis.Stream;
 import org.apache.skywalking.oap.server.core.analysis.record.Record;
 import org.apache.skywalking.oap.server.core.analysis.worker.RecordStreamProcessor;
 import org.apache.skywalking.oap.server.core.source.DefaultScopeDefine;
-import org.apache.skywalking.oap.server.core.storage.ShardingAlgorithm;
+import org.apache.skywalking.oap.server.core.storage.StorageID;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
 import org.apache.skywalking.oap.server.core.storage.annotation.Column;
+import org.apache.skywalking.oap.server.core.storage.annotation.ElasticSearch;
 import org.apache.skywalking.oap.server.core.storage.annotation.SQLDatabase;
 import org.apache.skywalking.oap.server.core.storage.annotation.SuperDataset;
 import org.apache.skywalking.oap.server.core.storage.type.Convert2Entity;
@@ -43,13 +42,14 @@ import org.apache.skywalking.oap.server.library.util.StringUtil;
 import zipkin2.Endpoint;
 import zipkin2.Span;
 
-import static org.apache.skywalking.oap.server.core.analysis.manual.segment.SegmentRecord.TRACE_ID;
+import java.util.List;
+import java.util.Map;
+
 import static org.apache.skywalking.oap.server.core.analysis.record.Record.TIME_BUCKET;
 
 @SuperDataset
 @Stream(name = ZipkinSpanRecord.INDEX_NAME, scopeId = DefaultScopeDefine.ZIPKIN_SPAN, builder = ZipkinSpanRecord.Builder.class, processor = RecordStreamProcessor.class)
 @SQLDatabase.ExtraColumn4AdditionalEntity(additionalTable = ZipkinSpanRecord.ADDITIONAL_QUERY_TABLE, parentColumn = TIME_BUCKET)
-@SQLDatabase.Sharding(shardingAlgorithm = ShardingAlgorithm.TIME_SEC_RANGE_SHARDING_ALGORITHM, dataSourceShardingColumn = TRACE_ID, tableShardingColumn = TIME_BUCKET)
 @BanyanDB.TimestampColumn(ZipkinSpanRecord.TIMESTAMP_MILLIS)
 public class ZipkinSpanRecord extends Record {
     private static final Gson GSON = new Gson();
@@ -80,95 +80,97 @@ public class ZipkinSpanRecord extends Record {
 
     @Setter
     @Getter
-    @Column(columnName = TRACE_ID)
+    @Column(name = TRACE_ID)
     @SQLDatabase.AdditionalEntity(additionalTables = {ADDITIONAL_QUERY_TABLE}, reserveOriginalColumns = true)
+    @BanyanDB.SeriesID(index = 0)
+    @ElasticSearch.Routing
     private String traceId;
     @Setter
     @Getter
-    @Column(columnName = SPAN_ID)
+    @Column(name = SPAN_ID)
+    @BanyanDB.SeriesID(index = 1)
     private String spanId;
     @Setter
     @Getter
-    @Column(columnName = PARENT_ID)
+    @Column(name = PARENT_ID)
     private String parentId;
     @Setter
     @Getter
-    @Column(columnName = NAME)
+    @Column(name = NAME)
     private String name;
     @Setter
     @Getter
-    @Column(columnName = DURATION)
+    @Column(name = DURATION)
     private long duration;
     @Setter
     @Getter
-    @Column(columnName = KIND)
+    @Column(name = KIND)
     private String kind;
     @Setter
     @Getter
-    @Column(columnName = TIMESTAMP_MILLIS)
+    @Column(name = TIMESTAMP_MILLIS)
     private long timestampMillis;
     @Setter
     @Getter
-    @Column(columnName = TIMESTAMP)
+    @Column(name = TIMESTAMP)
     private long timestamp;
     @Setter
     @Getter
-    @Column(columnName = LOCAL_ENDPOINT_SERVICE_NAME)
-    @BanyanDB.SeriesID(index = 0)
+    @Column(name = LOCAL_ENDPOINT_SERVICE_NAME)
     private String localEndpointServiceName;
     @Setter
     @Getter
-    @Column(columnName = LOCAL_ENDPOINT_IPV4, storageOnly = true)
+    @Column(name = LOCAL_ENDPOINT_IPV4, storageOnly = true)
     private String localEndpointIPV4;
     @Setter
     @Getter
-    @Column(columnName = LOCAL_ENDPOINT_IPV6, storageOnly = true)
+    @Column(name = LOCAL_ENDPOINT_IPV6, storageOnly = true)
     private String localEndpointIPV6;
     @Setter
     @Getter
-    @Column(columnName = LOCAL_ENDPOINT_PORT, storageOnly = true)
+    @Column(name = LOCAL_ENDPOINT_PORT, storageOnly = true)
     private int localEndpointPort;
     @Setter
     @Getter
-    @Column(columnName = REMOTE_ENDPOINT_SERVICE_NAME)
+    @Column(name = REMOTE_ENDPOINT_SERVICE_NAME)
     private String remoteEndpointServiceName;
     @Setter
     @Getter
-    @Column(columnName = REMOTE_ENDPOINT_IPV4, storageOnly = true)
+    @Column(name = REMOTE_ENDPOINT_IPV4, storageOnly = true)
     private String remoteEndpointIPV4;
     @Setter
     @Getter
-    @Column(columnName = REMOTE_ENDPOINT_IPV6, storageOnly = true)
+    @Column(name = REMOTE_ENDPOINT_IPV6, storageOnly = true)
     private String remoteEndpointIPV6;
     @Setter
     @Getter
-    @Column(columnName = REMOTE_ENDPOINT_PORT, storageOnly = true)
+    @Column(name = REMOTE_ENDPOINT_PORT, storageOnly = true)
     private int remoteEndpointPort;
     @Setter
     @Getter
-    @Column(columnName = ANNOTATIONS, storageOnly = true, length = 50000)
+    @Column(name = ANNOTATIONS, storageOnly = true, length = 50000)
     private JsonObject annotations;
     @Setter
     @Getter
-    @Column(columnName = TAGS, storageOnly = true, length = 50000)
+    @Column(name = TAGS, storageOnly = true, length = 50000)
     private JsonObject tags;
     @Setter
     @Getter
-    @Column(columnName = DEBUG)
+    @Column(name = DEBUG)
     private int debug;
     @Setter
     @Getter
-    @Column(columnName = SHARED)
+    @Column(name = SHARED)
     private int shared;
     @Setter
     @Getter
-    @Column(columnName = QUERY, indexOnly = true, length = QUERY_LENGTH)
+    @Column(name = QUERY, indexOnly = true, length = QUERY_LENGTH)
     @SQLDatabase.AdditionalEntity(additionalTables = {ADDITIONAL_QUERY_TABLE})
     private List<String> query;
 
     @Override
-    public String id() {
-        return traceId + Const.LINE + spanId;
+    public StorageID id() {
+        return new StorageID().append(TRACE_ID, traceId).append(SPAN_ID, spanId);
     }
 
     public static class Builder implements StorageBuilder<ZipkinSpanRecord> {
@@ -260,7 +262,9 @@ public class ZipkinSpanRecord extends Record {
         span.traceId(record.getTraceId());
         span.id(record.getSpanId());
         span.parentId(record.getParentId());
-        span.kind(Span.Kind.valueOf(record.getKind()));
+        if (!StringUtil.isEmpty(record.getKind())) {
+            span.kind(Span.Kind.valueOf(record.getKind()));
+        }
         span.timestamp(record.getTimestamp());
         span.duration(record.getDuration());
         span.name(record.getName());
