@@ -23,17 +23,19 @@ import org.apache.skywalking.banyandb.v1.client.BanyanDBClient;
 import org.apache.skywalking.banyandb.v1.client.MeasureBulkWriteProcessor;
 import org.apache.skywalking.banyandb.v1.client.MeasureQuery;
 import org.apache.skywalking.banyandb.v1.client.MeasureQueryResponse;
+import org.apache.skywalking.banyandb.v1.client.MeasureWrite;
 import org.apache.skywalking.banyandb.v1.client.StreamBulkWriteProcessor;
 import org.apache.skywalking.banyandb.v1.client.StreamQuery;
 import org.apache.skywalking.banyandb.v1.client.StreamQueryResponse;
 import org.apache.skywalking.banyandb.v1.client.StreamWrite;
-import org.apache.skywalking.banyandb.v1.client.grpc.exception.AlreadyExistsException;
 import org.apache.skywalking.banyandb.v1.client.TopNQuery;
 import org.apache.skywalking.banyandb.v1.client.TopNQueryResponse;
+import org.apache.skywalking.banyandb.v1.client.grpc.exception.AlreadyExistsException;
 import org.apache.skywalking.banyandb.v1.client.grpc.exception.BanyanDBException;
 import org.apache.skywalking.banyandb.v1.client.metadata.Group;
 import org.apache.skywalking.banyandb.v1.client.metadata.Measure;
 import org.apache.skywalking.banyandb.v1.client.metadata.Property;
+import org.apache.skywalking.banyandb.v1.client.metadata.PropertyStore;
 import org.apache.skywalking.banyandb.v1.client.metadata.Stream;
 import org.apache.skywalking.banyandb.v1.client.metadata.TopNAggregation;
 import org.apache.skywalking.oap.server.library.client.Client;
@@ -99,6 +101,17 @@ public class BanyanDBStorageClient implements Client, HealthCheckable {
         }
     }
 
+    public PropertyStore.DeleteResult deleteProperty(String group, String name, String id, String... tags) throws IOException {
+        try {
+            PropertyStore.DeleteResult result = this.client.deleteProperty(group, name, id, tags);
+            this.healthChecker.health();
+            return result;
+        } catch (BanyanDBException ex) {
+            healthChecker.unHealth(ex);
+            throw new IOException("fail to delete property", ex);
+        }
+    }
+
     public StreamQueryResponse query(StreamQuery q) throws IOException {
         try {
             StreamQueryResponse response = this.client.query(q);
@@ -185,6 +198,14 @@ public class BanyanDBStorageClient implements Client, HealthCheckable {
         }
     }
 
+    public StreamWrite createStreamWrite(String group, String name, String elementId) {
+        return this.client.createStreamWrite(group, name, elementId);
+    }
+
+    public MeasureWrite createMeasureWrite(String group, String name, long timestamp) {
+        return this.client.createMeasureWrite(group, name, timestamp);
+    }
+
     public void write(StreamWrite streamWrite) {
         this.client.write(streamWrite);
     }
