@@ -19,13 +19,9 @@
 package org.apache.skywalking.oap.server.storage.plugin.elasticsearch.base;
 
 import com.fasterxml.jackson.core.type.TypeReference;
+import com.google.common.base.Strings;
 import com.google.gson.Gson;
-import java.io.IOException;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Optional;
+import lombok.Setter;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.skywalking.library.elasticsearch.response.Index;
 import org.apache.skywalking.library.elasticsearch.response.IndexTemplate;
@@ -43,12 +39,21 @@ import org.apache.skywalking.oap.server.library.util.CollectionUtils;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
 import org.apache.skywalking.oap.server.storage.plugin.elasticsearch.StorageModuleElasticsearchConfig;
 
+import java.io.IOException;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Optional;
+
 @Slf4j
 public class StorageEsInstaller extends ModelInstaller {
     private final Gson gson = new Gson();
     private final StorageModuleElasticsearchConfig config;
     protected final ColumnTypeEsMapping columnTypeEsMapping;
     private final Map<String, Map<String, Object>> specificIndexesSettings;
+    @Setter
+    private int indexRefreshInterval = 30;
 
     /**
      * The mappings of the template .
@@ -86,12 +91,14 @@ public class StorageEsInstaller extends ModelInstaller {
                 Optional<Index> index = esClient.getIndex(tableName);
                 Mappings historyMapping = index.map(Index::getMappings).orElseGet(Mappings::new);
                 structures.putStructure(tableName, historyMapping, index.map(Index::getSettings).orElseGet(HashMap::new));
-                boolean containsMapping = structures.containsMapping(tableName, createMapping(model));
-                // Do not check index settings in the "no-init mode",
-                // because the no-init mode OAP server doesn't take responsibility for index settings.
                 if (RunningMode.isNoInitMode()) {
-                    exist = containsMapping;
+                    // Do not check index settings and field types in the "no-init mode",
+                    // because the no-init mode OAP server doesn't take responsibility for index settings
+                    // or updating field types, it just cares about whether the data can be ingested without
+                    // reporting errors.
+                    exist = structures.containsFieldNames(tableName, createMapping(model));
                 } else {
+                    boolean containsMapping = structures.containsMapping(tableName, createMapping(model));
                     exist = containsMapping && structures.compareIndexSetting(tableName, createSetting(model));
                 }
             }
@@ -101,7 +108,7 @@ public class StorageEsInstaller extends ModelInstaller {
         boolean templateExists = esClient.isExistsTemplate(tableName);
         final Optional<IndexTemplate> template = esClient.getTemplate(tableName);
 
-        if ((templateExists && !template.isPresent()) || (!templateExists && template.isPresent())) {
+        if ((templateExists && template.isEmpty()) || (!templateExists && template.isPresent())) {
             throw new Error("[Bug warning] ElasticSearch client query template result is not consistent. " +
                                 "Please file an issue to Apache SkyWalking.(https://github.com/apache/skywalking/issues)");
         }
@@ -112,12 +119,12 @@ public class StorageEsInstaller extends ModelInstaller {
             structures.putStructure(
                 tableName, template.get().getMappings(), template.get().getSettings()
             );
-            boolean containsMapping = structures.containsMapping(tableName, createMapping(model));
             // Do not check index settings in the "no-init mode",
             // because the no-init mode OAP server doesn't take responsibility for index settings.
             if (RunningMode.isNoInitMode()) {
-                exist = containsMapping;
+                exist = structures.containsFieldNames(tableName, createMapping(model));
             } else {
+                boolean containsMapping = structures.containsMapping(tableName, createMapping(model));
                 exist = containsMapping && structures.compareIndexSetting(tableName, createSetting(model));
             }
         }
@@ -236,18 +243,6 @@ public class StorageEsInstaller extends ModelInstaller {
         indexSettings.put("number_of_shards", model.isSuperDataset()
             ? Integer.toString(config.getIndexShardsNumber() * config.getSuperDatasetIndexShardsFactor())
             : Integer.toString(config.getIndexShardsNumber()));
-        // Set the index refresh period as INT(flushInterval * 2/3). At the edge case,
-        // in low traffic(traffic < bulkActions in the whole period), there is a possible case, 2 period bulks are included in
-        // one index refresh rebuild operation, which could cause version conflicts. And this case can't be fixed
-        // through `core/persistentPeriod` as the bulk fresh is not controlled by the persistent timer anymore.
-        int indexRefreshInterval = config.getFlushInterval() * 2 / 3;
-        if (indexRefreshInterval < 5) {
-            // The refresh interval should not be less than 5 seconds (the recommended default value = 10s),
-            // and the bulk flush interval should not be set less than 8s (the recommended default value = 15s).
-            // This is a precaution case which makes ElasticSearch server has reasonable refresh interval,
-            // even this value is set too small by end user manually.
-            indexRefreshInterval = 5;
-        }
         indexSettings.put("refresh_interval", indexRefreshInterval + "s");
         indexSettings.put("analysis", getAnalyzerSetting(model));
         if (!StringUtil.isEmpty(config.getAdvanced())) {
@@ -273,7 +268,7 @@ public class StorageEsInstaller extends ModelInstaller {
     private Map getAnalyzerSetting(Model model) throws StorageException {
         if (config.isLogicSharding() || !model.isTimeSeries()) {
             return getAnalyzerSettingByColumn(model);
-        } else if (IndexController.INSTANCE.isRecordModel(model) && model.isSuperDataset()) {
+        } else if (model.isRecord() && model.isSuperDataset()) {
             //SuperDataset doesn't merge index, the analyzer follow the column config.
             return getAnalyzerSettingByColumn(model);
         } else {
@@ -311,11 +306,11 @@ public class StorageEsInstaller extends ModelInstaller {
         Map<String, Object> properties = new HashMap<>();
         Mappings.Source source = new Mappings.Source();
         for (ModelColumn columnDefine : model.getColumns()) {
-            final String type = columnTypeEsMapping.transform(columnDefine.getType(), columnDefine.getGenericType());
+            final String type = columnTypeEsMapping.transform(columnDefine.getType(), columnDefine.getGenericType(), columnDefine.getElasticSearchExtension());
             String columnName = columnDefine.getColumnName().getName();
-            String alias = columnDefine.getElasticSearchExtension().getColumnAlias();
-            if (!config.isLogicSharding() && alias != null) {
-                columnName = alias;
+            String legacyName = columnDefine.getElasticSearchExtension().getLegacyColumnName();
+            if (config.isLogicSharding() && !Strings.isNullOrEmpty(legacyName)) {
+                columnName = legacyName;
             }
             if (columnDefine.getElasticSearchExtension().needMatchQuery()) {
                 String matchCName = MatchCNameBuilder.INSTANCE.build(columnName);
@@ -344,13 +339,13 @@ public class StorageEsInstaller extends ModelInstaller {
             }
         }
 
-        if ((IndexController.INSTANCE.isMetricModel(model) && !config.isLogicSharding())
+        if ((model.isMetric() && !config.isLogicSharding())
             || (config.isLogicSharding() && IndexController.INSTANCE.isFunctionMetric(model))) {
             Map<String, Object> column = new HashMap<>();
             column.put("type", "keyword");
             properties.put(IndexController.LogicIndicesRegister.METRIC_TABLE_NAME, column);
         }
-        if (!config.isLogicSharding() && IndexController.INSTANCE.isRecordModel(model) && !model.isSuperDataset()) {
+        if (!config.isLogicSharding() && model.isRecord() && !model.isSuperDataset()) {
             Map<String, Object> column = new HashMap<>();
             column.put("type", "keyword");
             properties.put(IndexController.LogicIndicesRegister.RECORD_TABLE_NAME, column);
