@@ -14,15 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+import esTitles from "./menus/es";
 const msg = {
+  ...esTitles,
   general: "Servicio General",
   services: "Servicios",
   service: "Servicio",
   traces: "Trazas",
   metrics: "Métricas",
-  serviceMesh: "Malla de Servicios",
-  infrastructure: "Infraestructura",
-  virtualMachine: "Máquina Virtual",
   dashboardNew: "Nuevo Panel",
   dashboardList: "Listado Paneles",
   logs: "Logs",
@@ -35,12 +34,9 @@ const msg = {
   mySQL: "MySQL/MariaDB",
   serviceName: "Nombre Servicio",
   technologies: "Tecnologías",
-  generalServicePanel: "Panel Servicio General",
   health: "Salud",
   groupName: "Nombre Grupo",
   topologies: "Topologías",
-  dataPanel: "Plano de Datos",
-  controlPanel: "Plano de Control",
   eventList: "Listado Eventos",
   newDashboard: "Crear panel nuevo",
   dashboardEdit: "Editar el panel",
@@ -117,20 +113,9 @@ const msg = {
   rename: "Renombrar",
   deleteTitle: "¿Está seguro que quiere eliminarlo?",
   rootTitle: "¿Está seguro que quiere establecerlo?",
-  selfObservability: "Autoobservabilidad",
-  satellite: "Satéllite",
-  skyWalkingServer: "Servidor SkyWalking",
-  functions: "Funciones",
-  browser: "Navegador",
-  linux: "Linux",
   editWarning: "Estás entrando en modo edición",
   viewWarning: "Estás entrando en modo visualización",
-  virtualDatabase: "Base de Datos Virtual",
-  virtualCache: "Caché virtual",
   reloadDashboards: "Recargar Panel",
-  kubernetesService: "Servicio",
-  kubernetesCluster: "Cluster",
-  kubernetes: "Kubernetes",
   textUrl: "Hipervínculo de Texto",
   textAlign: "Alineación de Texto",
   metricLabel: "Etiqueta de Métrica",
@@ -154,9 +139,7 @@ const msg = {
     "El nombre sólo admite chino e inglés, líneas horizontales y subrayado, y la longitud del nombre no excederá de 300 caracteres",
   enableAssociate: "Activar asociación",
   query: "Consulta",
-  postgreSQL: "PostgreSQL",
   endpointTips: "Aquí, la tabla muestra hasta 20 punto final.",
-  apisix: "APISIX",
   queryOrder: "Consulta por duración",
   setOrder: "Orden de consulta",
   latency: "Retraso",
@@ -280,7 +263,6 @@ const msg = {
   aggregation: "Cálculo",
   unit: "Unidad",
   labelsIndex: "Subíndice Etiqueta",
-  group: "Grupo Servicio",
   browserView: "Navegador",
   sortOrder: "Orden de clasificación",
   chartType: "Tipo Gráfico",
@@ -375,18 +357,6 @@ const msg = {
   conditionNotice:
     "Aviso: Por favor presione Intro después de introducir una clave de contenido, excluir clave de contenido(clave=valor).",
   language: "Lenguaje",
-  gateway: "Puerta",
-  virtualMQ: "MQ virtual",
-  AWSCloud: "AWS Cloud",
-  AWSCloudEKS: "EKS",
-  AWSCloudS3: "S3",
-  AWSCloudDynamoDB: "DynamoDB",
-  AWSGateway: "AWS API Gateway",
-  APIGateway: "API Gateway",
-  redis: "Redis",
-  elasticsearch: "Elasticsearch",
-  mq: "MQ",
-  rabbitMQ: "RabbitMQ",
   save: "Salvar",
   editStrategy: "Estrategia editorial",
   policyList: "Lista de políticas",
@@ -404,5 +374,13 @@ const msg = {
   detailLabel: "Detail Label",
   summary: "Summary",
   detail: "Detail",
+  marketplace: "Marketplace",
+  menus: "Menus",
+  saveReload: "Save and reload the page",
+  document: "Documentation",
+  metricMode: "Metric Mode",
+  addExpressions: "Add Expressions",
+  expressions: "Expression",
+  unhealthyExpression: "Unhealthy Expression",
 };
 export default msg;
